@@ -331,8 +331,14 @@ class Transaction(RipplePrimitive):
             'SetRegularKey': SetRegularKeyTransaction,
             'EnableAmendment': EnableAmendmentTransaction,
             'SeeFee': SetFeeTransaction,
-            'SignerListSet': SignerListSetTransaction
-        }[data['TransactionType']]
+            'SignerListSet': SignerListSetTransaction,
+            'PaymentChannelFund': PaymentChannelFundTransaction,
+            'PaymentChannelCreate': PaymentChannelCreateTransaction,
+            'PaymentChannelClaim': PaymentChannelClaimTransaction,
+            'EscrowFinish': EscrowFinishTransaction,
+            'EscrowCreate': EscrowCreateTransaction,
+            'EscrowCancel': EscrowCancelTransaction,
+        }.get(data['TransactionType'], UnknownTransaction)
         self.__class__ = subclass
 
     @property
@@ -674,6 +680,35 @@ class SignerListSetTransaction(Transaction):
     pass
 
 
+class EscrowCreateTransaction(Transaction):
+    pass
+
+
+class EscrowCancelTransaction(Transaction):
+    pass
+
+
+class EscrowFinishTransaction(Transaction):
+    pass
+
+
+class PaymentChannelClaimTransaction(Transaction):
+    pass
+
+
+class PaymentChannelCreateTransaction(Transaction):
+    pass
+
+
+class PaymentChannelFundTransaction(Transaction):
+    pass
+
+
+class UnknownTransaction(Transaction):
+    pass
+
+
+
 class TransactionSubscriptionMessage(RipplePrimitive):
     """The data structure returned by the server when subscribing to
     transaction updates.
