@@ -31,6 +31,12 @@ def test_payment_xrp():
     assert tx.analyze_path() == {'offers': 0, 'intermediaries': 0}
 
 
+def test_payment_delivered_amount_xrp():
+    txstr = open_transaction('payment_delivered_amount_xrp.json')
+    tx = Transaction(txstr)
+    assert tx.amount_received == (Decimal('0.000955'), 'XRP', None)
+
+
 def test_payment_to_trusting_party():
     txstr = open_transaction('payment_to_trusting_party.json')
     tx = Transaction(txstr)
@@ -87,7 +93,7 @@ def test_payment_with_intermediary_traders():
     assert tx.analyze_path() == {'offers': 2, 'intermediaries': 2}
 
 
-@pytest.mark.failing
+@pytest.mark.xfail()
 def test_payment_usd_to_xrp_lending_from_payee():
     txstr = open_transaction('payment_usd_to_xrp_lending_from_payee.json')
     tx = Transaction(txstr)
@@ -174,7 +180,7 @@ def test_payment_account_creation():
     assert tx.amount_received == (Decimal('35'), 'XRP', None)
 
 
-@pytest.mark.failing
+@pytest.mark.xfail()
 def test_payment_unknown():
     txstr = open_transaction('payment_unknown.json')
     tx = Transaction(txstr)
